/*
 * System Event Log
 * 
 * Copyright (c) RegExLab.com
 * 
 * 2006.03.27 Chongqing China.
 */
package com.regexlab.j2e;

/**
 * This class implements an event log.
 * It is based directly upon the Win32 event log APIs,
 * RegisterEventSource, ReportEvent, and DeregisterEventSource.
 * 
 * <p>For more information on implementing and using event logs,
 * see the Win32 documentation
 * 
 * <p>Copyright 2006 (c) RegExLab.com
 *
 * @author sswater shi
 */
public class EventLog
{
    /** Indicates a success event */
    public static final short SUCCESS        =  0x0000;
    
    /** Indicates an error event */
    public static final short ERROR          =  0x0001;
    
    /** Indicates a warning event */
    public static final short WARNING        =  0x0002;
    
    /** Indicates an information event */
    public static final short INFORMATION    =  0x0004;
    
    /** Indicates a success audit event */
    public static final short AUDIT_SUCCESS  =  0x0008;
    
    /** Indicates a failure audit event */
    public static final short AUDIT_FAILURE  =  0x0010;

    /**
     * Creates an EventLog object with app name
     */
    public EventLog ()
    {
        init(null, null);
    }
    
    /**
     * Creates an EventLog object given the name of the source
     * 
     * @param source The name of the source referenced by the EventLog object.
     */
    public EventLog (String source)
    {
        init(null, source);
    }
    
    /**
     * Creates an EventLog object given the name of the source and the name of the server.
     * 
     * @param server The Universal Naming Convention (UNC) name 
     *               of the server that this operation is to be performed on.
     * @param source The name of the source referenced by the EventLog object.
     */
    public EventLog (String server, String source)
    {
        init(server, source);
    }

    /**
     * Writes an entry at the end of the event log
     * 
     * @param type The type of event being logged
     * @param cat  The event category
     * @param id   The event identifier, which specifies the message that goes with
     *             this event as an entry in the message file associated with the event source
     */
    public void reportEvent (short type, short cat, int id)
    {
        reportEvent(type, cat, id, (String[])null, null);
    }
    
    /**
     * Writes an entry at the end of the event log, providing an associated string
     * 
     * @param type The type of event being logged
     * @param cat  The event category
     * @param id   The event identifier, which specifies the message that goes with
     *             this event as an entry in the message file associated with the event source
     * @param msg  A string that is merged into the message before the message is displayed to the user
     */
    public void reportEvent (short type, short cat, int id, String msg)
    {
        reportEvent(type, cat, id, new String[]{msg}, null);
    }
    
    /**
     * Writes an entry at the end of the event log, providing associated strings
     * 
     * @param type The type of event being logged
     * @param cat  The event category
     * @param id   The event identifier, which specifies the message that goes with
     *             this event as an entry in the message file associated with the event source
     * @param msgs An array of strings that are merged into the message before the message is displayed to the user
     */
    public void reportEvent (short type, short cat, int id, String[] msgs)
    {
        reportEvent(type, cat, id, msgs, null);
    }
    
    /**
     * Writes an entry at the end of the event log, providing an associated string and binary data
     * 
     * @param type The type of event being logged
     * @param cat  The event category
     * @param id   The event identifier, which specifies the message that goes with
     *             this event as an entry in the message file associated with the event source
     * @param msg  A string that is merged into the message before the message is displayed to the user
     * @param data The binary data associated with the report
     */
    public void reportEvent (short type, short cat, int id, String msg, byte[] data)
    {
        reportEvent(type, cat, id, new String[]{msg}, data);
    }

    /**
     * Writes an entry at the end of the event log, providing associated strings and binary data
     * 
     * @param type The type of event being logged
     * @param cat  The event category
     * @param id   The event identifier, which specifies the message that goes with
     *             this event as an entry in the message file associated with the event source
     * @param msgs An array of strings that are merged into the message before the message is displayed to the user
     * @param data The binary data associated with the report
     */
    public native void reportEvent (short type, short cat, int id, String[] msgs, byte[] data);

    protected native void init(String server, String source);
    protected native void finalize ();
    protected int h = 0;

    static
    {
        String j2epath = System.getProperty("j2e.app.path");
        if( j2epath != null )
            System.load( j2epath );
    }
}

